#!/bin/bash
#
# Zenwalk build file for root
# Author: Mark Colclough
# Date:   3 March 2007

# Per-package settings
# source ftp://root.cern.ch/root/root_v5.14.00c.source.tar.gz
# home page http://root.cern.ch/
tarball='root_v5.14.00c.source.tar.gz'  # unconventional
patch=''
srcname='root'
srcversion='5.14.0.c'
pkgversion='46.1'
arch='i486'
cpu='i686'

#       |-----handy-ruler------------------------------------------------------|
descfile="\
$srcname: $srcname (Object-Oriented Data Analysis Framework from CERN)
$srcname:
$srcname: Root is a C++ framework on which to build data acquisition,
$srcname: simulation and data analysis systems.  It works in batch or
$srcname: interactive mode, and provides multidimensional curve plotting,
$srcname: fitting, function evaluation, minimisation, graphics and 
$srcname: visualization classes.
$srcname: 
$srcname: 
$srcname:
$srcname:"

# Delete if no desktop file is wanted.
# see http://standards.freedesktop.org/menu-spec/latest
desktopfile="\
[Desktop Entry]
Type=Application
Name=CERN-root
Comment=Data analysis system
Icon=rootcern
Exec=root
Terminal=true
Categories=Science;Graphics"

# Delete if no custom doinst.sh is wanted.
doinstfile=\
'grep -q "^/usr/lib/root$" etc/ld.so.conf || echo "/usr/lib/root" >> etc/ld.so.conf
ldconfig'

#############  Nothing to touch here  ############################
#############  Zip down to the do_configure block and beyond  ####
#############  to find things that might need attention.      ####
# Compute useful variables
package="$srcname-$srcversion-$arch-$pkgversion"
builddir=$(pwd)
srcdir="$builddir/$srcname-$srcversion"
destdir="$builddir/$package"
buildlog="$builddir/$srcname-buildlog"

# Prevent any rm -rf accidents from happening too close to the root
if [ ${#builddir} -lt 9 ] ; then
	echo "You don't want to build in $builddir"
	exit 1
fi

# Useful functions
INS755="install -o root -g root -m 755"
INS644="install -o root -g root -m 644"

# Logic to permit incremental building ...
# Special commands
if [ "$1" = "clean" -o "$1" = "-clean" ] ; then
	rm -rf $buildlog $destdir $srcdir 
	exit 0
fi

# Determine which stages to execute
[ ! $1 ] && defaultargs='-xpcmiadstv'
while getopts 'hxpcmiadstvr' stage $defaultargs
do
	[ $stage = 'h' ] && do_help=1
	[ $stage = 'x' ] && do_extract=1
	[ $stage = 'p' ] && do_prepare=1
	[ $stage = 'c' ] && do_configure=1
	[ $stage = 'm' ] && do_make=1
	[ $stage = 'i' ] && do_install=1
	[ $stage = 'a' ] && do_additions=1
	[ $stage = 'd' ] && do_deletes=1
	[ $stage = 's' ] && do_strip=1
	[ $stage = 't' ] && do_tar=1
	[ $stage = 'v' ] && do_verify=1
	[ $stage = 'r' ] && do_requirements=1
done

if [ $do_help ] ; then
	cat <<EOF
	$0 opts   Where opts are:
	-h : show this help
	-x : extract source
	-p : prepare destination tree
	-c : configure
	-m : make
	-i : make install
	-a : add doc files to destination
	-d : delete unwanted installed files
	-s : strip
	-t : tar.gz the package
	-v : verify the package
	-r : find requirements
	clean : clean up build directory
	No arguments : full build (all above except help and requirements, in order).
EOF
exit 0
fi # do_help

# ################ Start of build steps ######################
(
rm -f $buildlog
echo "== Building package $package in directory $builddir =="
echo "command is $0 $1"

if [ $do_extract ] ; then
	echo "== preparing source tree at $srcdir =="
	cd $builddir
	rm -rf $srcdir
	tar xf $tarball
	if [ ! $? ] ; then
		echo "Failed to extract $tarball"
		exit 1
	fi
	
	# fix source directory name 
	mv root $srcname-$srcversion
	
	if [ $patch ] ; then
		echo "== patching $srcname-$srcversion =="
		( cd $srcdir ; patch -p1 < ../$patch )
	fi
	
	chown -R root:root $srcdir
fi # do_extract


if [ $do_prepare ] ; then
	echo "== preparing destination tree at $destdir =="
	cd $builddir
	rm -rf $destdir
	mkdir -p $destdir/install
	echo "$descfile" > $destdir/install/slack-desc
		
	if [ -n "$doinstfile" ] ; then
		echo "$doinstfile" > $destdir/install/doinst.sh
	fi
	
	mkdir -p $destdir/usr/doc/$srcname-$srcversion
	mkdir -p $destdir/usr/src/$srcname-$srcversion
	if [ $patch ] ; then
		echo "== adding patch to tree =="
		$INS644 $patch $destdir/usr/src/$srcname-$srcversion/
	fi
fi # do_prepare


if [ $do_configure ] ; then
	echo "== configure in $srcdir =="
	cd $srcdir
	./configure --prefix=/usr \
	            --mandir=/usr/man/man1 \
	            --docdir=/usr/doc/$srcname-$srcversion \
	            --disable-builtin-freetype \
	            --disable-builtin-pcre \
	            --disable-builtin-zlib \
	            --enable-minuit2 \
	            --enable-soversion
fi # do_configure


if [ $do_make ] ; then
	echo "== make in $srcdir =="
	cd $srcdir
	make
# These don't play well with the makefile, and since it's a 40
# minute build to find out...
#	   CFLAGS="-O2 -march=$arch -mtune=$cpu" \
#	   CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \
#	   CINTCFLAGS="-O2 -march=$arch -mtune=$cpu" \
#	   CINTCXXFLAGS="-O2 -march=$arch -mtune=$cpu"
fi # do_make


if [ $do_install ] ; then
	echo "== make install in $srcdir =="
	cd $srcdir
	make install DESTDIR=$destdir
fi # do_install

######### Edit according to what docs etc. are available ######## 
if [ $do_additions ] ; then
	echo "== doing additions =="
	if [ -n "$desktopfile" ] ; then
		mkdir -p $destdir/usr/share/applications
		echo "$desktopfile" > $destdir/usr/share/applications/$srcname.desktop
	fi
	
	# Need a better application icon, but for now...
	$INS644 $builddir/rootcern.png $destdir/usr/src/$srcname-$srcversion/
	mkdir -p $destdir/usr/share/icons/hicolor/48x48/apps/
	$INS644 $builddir/rootcern.png $destdir/usr/share/icons/hicolor/48x48/apps/
	
fi # do_additions

if [ $do_deletes ] ; then
   echo "== doing deletes =="
   echo "no deletes"
fi # do_deletes

######### Edit according to what needs to be stripped/zipped ########
if [ $do_strip ] ; then
	echo "== strip and compress =="
	cd $destdir
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
	if [ -d "$destdir/usr/man" ] ; then
		cd $destdir/usr/man
		find . | xargs file | grep "troff" | cut -f 1 -d : | xargs gzip -9
	fi
	
	if [ -d "$destdir/usr/info" ] ; then
		cd $destdir/usr/info
		find . | xargs file | grep -v "gzip" | cut -f 1 -d : | xargs gzip -9
	fi
	
	#for boringdocs in LICENSE ;  do 
	#	gzip -9 $destdir/usr/doc/$srcname-$srcversion/$boringdocs
	#done
fi # do_strip

###########  Nothing to do below here  #####################

if [ $do_tar ] ; then
    echo "== adding build script =="
    # Add script late because we may have been editing it during the build
    $INS755 $builddir/build-$srcname.sh $destdir/usr/src/$srcname-$srcversion/
    echo "== making package =="
    cd $destdir
    makepkg -p -l y -c n $destdir.tgz
    cd $builddir
    md5sum $package.tgz >$package.md5
fi # do_tar


if [ $do_verify ] ; then
    echo "== verifying package =="
    cd $builddir
    pkgcheck -z $package.tgz
    zen_pkgcheck_new.pl $package.tgz
fi # do_verify


if [ $do_requirements ] ; then
	echo "== determining dependencies =="
	requiredbuilder -z $package.tgz > $package.dep
fi # do_requirements


echo "== all done =="
) 2>&1 | tee $buildlog 
